<?php

namespace Btravel\Externalshipdata\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Btravel\Externalshipdata\Http\Requests\ExternalShipdataRequest;
use Btravel\Externalshipdata\Interfaces\ExternalShipdataRepositoryInterface;
use Btravel\Externalshipdata\Models\ExternalShipdata;

/**
 * Resource controller class for external_shipdata.
 */
class ExternalShipdataResourceController extends BaseController
{

    /**
     * Initialize external_shipdata resource controller.
     *
     * @param type ExternalShipdataRepositoryInterface $external_shipdata
     *
     * @return null
     */
    public function __construct(ExternalShipdataRepositoryInterface $external_shipdata)
    {
        parent::__construct();
        $this->repository = $external_shipdata;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Btravel\Externalshipdata\Repositories\Criteria\ExternalShipdataResourceCriteria::class);
    }

    /**
     * Display a list of external_shipdata.
     *
     * @return Response
     */
    public function index(ExternalShipdataRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Btravel\Externalshipdata\Repositories\Presenter\ExternalShipdataPresenter::class)
                ->$function();
        }

        $external_shipdatas = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('externalshipdata::external_shipdata.names'))
            ->view('externalshipdata::external_shipdata.index', true)
            ->data(compact('external_shipdatas', 'view'))
            ->output();
    }

    /**
     * Display external_shipdata.
     *
     * @param Request $request
     * @param Model   $external_shipdata
     *
     * @return Response
     */
    public function show(ExternalShipdataRequest $request, ExternalShipdata $external_shipdata)
    {

        if ($external_shipdata->exists) {
            $view = 'externalshipdata::external_shipdata.show';
        } else {
            $view = 'externalshipdata::external_shipdata.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('externalshipdata::external_shipdata.name'))
            ->data(compact('external_shipdata'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new external_shipdata.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ExternalShipdataRequest $request)
    {

        $external_shipdata = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('externalshipdata::external_shipdata.name')) 
            ->view('externalshipdata::external_shipdata.create', true) 
            ->data(compact('external_shipdata'))
            ->output();
    }

    /**
     * Create new external_shipdata.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ExternalShipdataRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $external_shipdata                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('externalshipdata::external_shipdata.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externalshipdata/external_shipdata/' . $external_shipdata->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/externalshipdata/external_shipdata'))
                ->redirect();
        }

    }

    /**
     * Show external_shipdata for editing.
     *
     * @param Request $request
     * @param Model   $external_shipdata
     *
     * @return Response
     */
    public function edit(ExternalShipdataRequest $request, ExternalShipdata $external_shipdata)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('externalshipdata::external_shipdata.name'))
            ->view('externalshipdata::external_shipdata.edit', true)
            ->data(compact('external_shipdata'))
            ->output();
    }

    /**
     * Update the external_shipdata.
     *
     * @param Request $request
     * @param Model   $external_shipdata
     *
     * @return Response
     */
    public function update(ExternalShipdataRequest $request, ExternalShipdata $external_shipdata)
    {
        try {
            $attributes = $request->all();

            $external_shipdata->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('externalshipdata::external_shipdata.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('externalshipdata/external_shipdata/' . $external_shipdata->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externalshipdata/external_shipdata/' . $external_shipdata->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the external_shipdata.
     *
     * @param Model   $external_shipdata
     *
     * @return Response
     */
    public function destroy(ExternalShipdataRequest $request, ExternalShipdata $external_shipdata)
    {
        try {

            $external_shipdata->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externalshipdata::external_shipdata.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('externalshipdata/external_shipdata/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('externalshipdata/external_shipdata/' . $external_shipdata->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple external_shipdata.
     *
     * @param Model   $external_shipdata
     *
     * @return Response
     */
    public function delete(ExternalShipdataRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('externalshipdata::external_shipdata.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('externalshipdata/external_shipdata'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externalshipdata/external_shipdata'))
                ->redirect();
        }

    }

    /**
     * Restore deleted external_shipdatas.
     *
     * @param Model   $external_shipdata
     *
     * @return Response
     */
    public function restore(ExternalShipdataRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('externalshipdata::external_shipdata.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/externalshipdata/external_shipdata'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/externalshipdata/external_shipdata/'))
                ->redirect();
        }

    }

}
