<?php

namespace Btravel\Externalshipdata\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Externalshipdata\Models\ExternalShipdata;

class ExternalShipdataPolicy
{

    /**
     * Determine if the given user can view the external_shipdata.
     *
     * @param UserPolicy $user
     * @param ExternalShipdata $external_shipdata
     *
     * @return bool
     */
    public function view(UserPolicy $user, ExternalShipdata $external_shipdata)
    {
        if ($user->canDo('externalshipdata.external_shipdata.view') && $user->isAdmin()) {
            return true;
        }

        return $external_shipdata->user_id == user_id() && $external_shipdata->user_type == user_type();
    }

    /**
     * Determine if the given user can create a external_shipdata.
     *
     * @param UserPolicy $user
     * @param ExternalShipdata $external_shipdata
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('externalshipdata.external_shipdata.create');
    }

    /**
     * Determine if the given user can update the given external_shipdata.
     *
     * @param UserPolicy $user
     * @param ExternalShipdata $external_shipdata
     *
     * @return bool
     */
    public function update(UserPolicy $user, ExternalShipdata $external_shipdata)
    {
        if ($user->canDo('externalshipdata.external_shipdata.edit') && $user->isAdmin()) {
            return true;
        }

        return $external_shipdata->user_id == user_id() && $external_shipdata->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given external_shipdata.
     *
     * @param UserPolicy $user
     * @param ExternalShipdata $external_shipdata
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ExternalShipdata $external_shipdata)
    {
        return $external_shipdata->user_id == user_id() && $external_shipdata->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given external_shipdata.
     *
     * @param UserPolicy $user
     * @param ExternalShipdata $external_shipdata
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ExternalShipdata $external_shipdata)
    {
        if ($user->canDo('externalshipdata.external_shipdata.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given external_shipdata.
     *
     * @param UserPolicy $user
     * @param ExternalShipdata $external_shipdata
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ExternalShipdata $external_shipdata)
    {
        if ($user->canDo('externalshipdata.external_shipdata.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
