<?php

namespace Btravel\Externalshipdata\Providers;

use Illuminate\Support\ServiceProvider;

class ExternalshipdataServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'externalshipdata');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'externalshipdata');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerExternalshipdata();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerExternalshipdata()
    {
        $this->app->bind('externalshipdata', function($app) {
            return new Externalshipdata($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Externalshipdata', 'Lavalite\Externalshipdata\Facades\Externalshipdata');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.externalshipdata', function ($app) {
            return $this->app->make('Btravel\Externalshipdata\Externalshipdata');
        });

                // Bind ExternalShipdata to repository
        $this->app->bind(
            'Btravel\Externalshipdata\Interfaces\ExternalShipdataRepositoryInterface',
            \Btravel\Externalshipdata\Repositories\Eloquent\ExternalShipdataRepository::class
        );

        $this->app->register(\Btravel\Externalshipdata\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Externalshipdata\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and externalshipdata's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/externalshipdata.php', 'externalshipdata'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeExternalshipdata::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.externalshipdata'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/externalshipdata.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/externalshipdata')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/externalshipdata')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
